@@ -1,15 +1,13 @@
 package Language::Prolog::Yaswi::Low;
 
-our $VERSION = '0.22_01'; # TRIAL
-$VERSION =~ tr/_//d;
+our $VERSION = '0.01';
 
 use strict;
 use warnings;
 
 require Exporter;
-our @ISA = qw(Exporter DynaLoader);
+our @ISA = qw(Exporter);
 our @EXPORT = qw( init
-		  cleanup
 		  toplevel
 		  openquery
 		  cutquery
@@ -21,16 +19,17 @@ our @EXPORT = qw( init
 		  getallvars
 		  $converter );
 
+
 use Carp;
 use Language::Prolog::Types::Converter;
 
-our $converter = Language::Prolog::Types::Converter->new();
+our $converter=Language::Prolog::Types::Converter->new();
+our @args;
 
 # our @fids;
 
 our ($qid, $query, @vars, @cells, %vars_cache);
 
-
 sub getvar ($) {
     my $name=$_[0]->name();
     croak "no such variable '$name'"
@@ -46,31 +45,36 @@ sub getquery () {
     swi2perl($query);
 }
 
-# require XSLoader;
-# XSLoader::load('Language::Prolog::Yaswi::Low', $VERSION);
+require XSLoader;
+XSLoader::load('Language::Prolog::Yaswi::Low', $VERSION);
 
-our $dl_load_flags;
-$dl_load_flags = 0x1 unless defined $dl_load_flags;
-sub dl_load_flags { $dl_load_flags }
+@args=(plexe(), '-q');
 
-require DynaLoader;
-use Alien::SWIProlog;
-__PACKAGE__->bootstrap;
+our %opaque;
 
-our @args;
-@args = (PL_EXE(), '-q') unless @args;
-
-sub init {
-    @args=(PL_EXE(), @_);
-    start();
+sub register_opaque {
+    my $obj=shift;
+    my $p=OPAQUE_PREFIX().sprintf("%x", ref2int($obj));
+    exists $opaque{$p} or
+	$opaque{$p}=$obj;
+    return $p;
 }
 
+sub unregister_opaque {
+    my $p=shift;
+    delete $opaque{$p}
+}
+
+sub get_opaque {
+    my $p=shift;
+    exists $opaque{$p}
+	or croak "trying to retrieve opaque from non existant key '$p'";
+    $opaque{$p}
+}
 
 1;
 __END__
 
-=encoding UTF-8
-
 =head1 NAME
 
 Language::Prolog::Yaswi::Low - Low level interface to SWI-Prolog
@@ -79,31 +83,31 @@ Language::Prolog::Yaswi::Low - Low level interface to SWI-Prolog
 
 
   # don't use Language::Prolog::Yaswi::Low;
-  use Language::Prolog::Yaswi; # instead ;-)
+  use Language::Prolog::Yaswi; #instead ;-)
 
 =head1 ABSTRACT
 
 
 =head1 DESCRIPTION
 
-Low level interface to SWI-Prolog.
+Stub documentation for Language::Prolog::Yaswi::Low, created by h2xs.
 
-=head2 SETTINGS
+=head2 EXPORT
+
+lots of things by default.
 
-The variable C<$Language::Prolog::Yaswi::Low::dl_load_flags> can be
-used to change the way the XS part of the module is loaded. The
-default value (0x01) allows to use Prolog extensions written in C in
-most architectures but it could introduce conflicts with other Perl
-modules.
 
 =head1 SEE ALSO
 
-L<Language::Prolog::Yaswi>.
+L<Language::Prolog::Yaswi>
 
+=head1 AUTHOR
+
+Salva, E<lt>sfandino@yahoo.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2006, 2008 by Salvador Fandiño (sfandino@yahoo.com).
+Copyright 2003 by Salvador Fandio
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
